@@ -6,23 +6,23 @@ from attrs import define, field
 from resoto_plugin_aws.resource.autoscaling import AwsAutoScalingGroup
 from resoto_plugin_aws.resource.base import AwsResource, GraphBuilder, AwsApiSpec
 from resoto_plugin_aws.resource.iam import AwsIamRole
-from resotolib.baseresources import BaseAccount, EdgeType, ModelReference  # noqa: F401
+from resotolib.baseresources import ModelReference
 from resotolib.json_bender import Bender, S, Bend, ForallBend
 from resotolib.types import Json
 from resoto_plugin_aws.aws_client import AwsClient
 
 
-# todo: annotate with no serialization annotation
+# noinspection PyUnresolvedReferences
 class EKSTaggable:
     def update_resource_tag(self, client: AwsClient, key: str, value: str) -> bool:
         if isinstance(self, AwsResource):
             if spec := self.api_spec:
                 client.call(
-                    service=spec.service,
-                    action="tag_resource",
+                    aws_service=spec.service,
+                    action="tag-resource",
                     result_name=None,
                     resourceArn=self.arn,
-                    tags=[{key: value}],
+                    tags={key: value},
                 )
                 return True
             return False
@@ -32,8 +32,8 @@ class EKSTaggable:
         if isinstance(self, AwsResource):
             if spec := self.api_spec:
                 client.call(
-                    service=spec.service,
-                    action="untag_resource",
+                    aws_service=spec.service,
+                    action="untag-resource",
                     result_name=None,
                     resourceArn=self.arn,
                     tagKeys=[key],
@@ -42,6 +42,10 @@ class EKSTaggable:
             return False
         return False
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [AwsApiSpec("eks", "tag-resource"), AwsApiSpec("eks", "untag-resource")]
+
 
 @define(eq=False, slots=False)
 class AwsEksNodegroupScalingConfig:
@@ -193,14 +197,18 @@ class AwsEksNodegroup(EKSTaggable, AwsResource):
 
     def delete_resource(self, client: AwsClient) -> bool:
         client.call(
-            service="eks",
-            action="delete_nodegroup",
+            aws_service="eks",
+            action="delete-nodegroup",
             result_name=None,
             clusterName=self.cluster_name,
             nodegroupName=self.name,
         )
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return super().called_mutator_apis() + [AwsApiSpec("eks", "delete-nodegroup")]
+
 
 @define(eq=False, slots=False)
 class AwsEksVpcConfigResponse:
@@ -293,9 +301,9 @@ class AwsEksCluster(EKSTaggable, AwsResource):
     kind: ClassVar[str] = "aws_eks_cluster"
     api_spec: ClassVar[AwsApiSpec] = AwsApiSpec("eks", "list-clusters", "clusters")
     reference_kinds: ClassVar[ModelReference] = {
-        "successors": {
+        "predecessors": {
             "default": ["aws_iam_role"],
-            "delete": [],
+            "delete": ["aws_iam_role"],
         }
     }
     mapping: ClassVar[Dict[str, Bender]] = {
@@ -333,6 +341,15 @@ class AwsEksCluster(EKSTaggable, AwsResource):
     cluster_encryption_config: List[AwsEksEncryptionConfig] = field(factory=list)
     cluster_connector_config: Optional[AwsEksConnectorConfig] = field(default=None)
 
+    @classmethod
+    def called_collect_apis(cls) -> List[AwsApiSpec]:
+        return [
+            cls.api_spec,
+            AwsApiSpec("eks", "describe-cluster"),
+            AwsApiSpec("eks", "list-nodegroups"),
+            AwsApiSpec("eks", "describe-nodegroup"),
+        ]
+
     @classmethod
     def collect(cls: Type[AwsResource], json: List[Json], builder: GraphBuilder) -> None:
         for name in cast(List[str], json):
@@ -349,11 +366,17 @@ class AwsEksCluster(EKSTaggable, AwsResource):
                         builder.add_node(ng, ng_json)
 
     def connect_in_graph(self, builder: GraphBuilder, source: Json) -> None:
-        builder.add_edge(self, EdgeType.default, clazz=AwsIamRole, arn=self.cluster_role_arn)
+        builder.dependant_node(
+            self, reverse=True, delete_same_as_default=True, clazz=AwsIamRole, arn=self.cluster_role_arn
+        )
 
     def delete_resource(self, client: AwsClient) -> bool:
-        client.call(service=self.api_spec.service, action="delete_cluster", result_name=None, name=self.name)
+        client.call(aws_service=self.api_spec.service, action="delete-cluster", result_name=None, name=self.name)
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return super().called_mutator_apis() + [AwsApiSpec("eks", "delete-cluster")]
+
 
 resources: List[Type[AwsResource]] = [AwsEksNodegroup, AwsEksCluster]
