@@ -68,16 +68,16 @@ class AwsKmsKey(AwsResource, BaseAccessKey):
         "kms_mac_algorithms": S("MacAlgorithms", default=[]),
     }
 
-    kms_aws_account_id: str = field(default=None)
-    kms_enabled: bool = field(default=None)
-    kms_description: str = field(default=None)
-    kms_key_usage: str = field(default=None)
-    kms_origin: str = field(default=None)
-    kms_key_manager: str = field(default=None)
-    kms_customer_master_key_spec: str = field(default=None)
-    kms_key_spec: str = field(default=None)
+    kms_aws_account_id: Optional[str] = field(default=None)
+    kms_enabled: Optional[bool] = field(default=None)
+    kms_description: Optional[str] = field(default=None)
+    kms_key_usage: Optional[str] = field(default=None)
+    kms_origin: Optional[str] = field(default=None)
+    kms_key_manager: Optional[str] = field(default=None)
+    kms_customer_master_key_spec: Optional[str] = field(default=None)
+    kms_key_spec: Optional[str] = field(default=None)
     kms_encryption_algorithms: List[str] = field(factory=list)
-    kms_multi_region: bool = field(default=None)
+    kms_multi_region: Optional[bool] = field(default=None)
     kms_deletion_date: Optional[str] = field(default=None)
     kms_valid_to: Optional[str] = field(default=None)
     kms_custom_key_store_id: Optional[str] = field(default=None)
